OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "Compartició federada",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Voleu afegir la compartició remota {nom} des de {owner}@{remote}?",
    "Remote share" : "Compartició remota",
    "Remote share password" : "Contrasenya de compartició remota",
    "Cancel" : "Cancel·la",
    "Add remote share" : "Afegeix compartició remota",
    "Copy" : "Copia",
    "Copied!" : "Copiat!",
    "Not supported!" : "No soportat!",
    "Press ⌘-C to copy." : "Premeu ⌘-C per copiar.",
    "Press Ctrl-C to copy." : "Premeu CTRL+C per copiar.",
    "Invalid Federated Cloud ID" : "ID de núvol federat no vàlid",
    "Server to server sharing is not enabled on this server" : "La compartició entre servidors no està activada en aquest servidor",
    "Couldn't establish a federated share." : "No s'ha pogut establir una part federada.",
    "Couldn't establish a federated share, maybe the password was wrong." : "No s'ha pogut establir una acció compartida federada, potser la contrasenya era incorrecta.",
    "Federated Share request sent, you will receive an invitation. Check your notifications." : "S'ha enviat la sol·licitud de participació federada, rebreu una invitació. Comproveu les vostres notificacions.",
    "Couldn't establish a federated share, it looks like the server to federate with is too old (Nextcloud <= 9)." : "No s’ha pogut establir una acció compartida federada, sembla que el servidor amb el qual s’ha federat és massa antic (Nextcloud <= 9).",
    "It is not allowed to send federated group shares from this server." : "No es permet enviar de grups de compartits federats des d'aquest servidor.",
    "Sharing %1$s failed, because this item is already shared with %2$s" : "No s'ha pogut compartir %1$s, perquè aquest element ja està compartit amb %2$s",
    "Not allowed to create a federated share with the same user" : "No està permés crear una compartició federada amb el mateix usuari",
    "File is already shared with %s" : "El fitxer ja està compartit amb %s",
    "Sharing %1$s failed, could not find %2$s, maybe the server is currently unreachable or uses a self-signed certificate." : "Ha fallat la compartició %1$s, no s'ha pogut trobar %2$s, potser el servidor és inaccessible actualment o fa servir un certificat auto-signat.",
    "Could not find share" : "No s'ha pogut trobar la compartició",
    "You received \"%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "Heu rebut \"/%3$s\" com una compartició remota des de %1$s (de part de %2$s)",
    "You received {share} as a remote share from {user} (on behalf of {behalf})" : "Heu rebut {share} com un recompte remot de {user} (en nom de {nom})",
    "You received \"%3$s\" as a remote share from %1$s" : "Heu rebut \"/%3$s\" com una compartició remota de %1$s",
    "You received {share} as a remote share from {user}" : "Heu rebut {share} com a recompte remot de {user}",
    "Accept" : "Accepta",
    "Decline" : "Denega",
    "Share with me through my #Nextcloud Federated Cloud ID, see %s" : "Compartiu amb mi a través de la meva #Nextcloud Federated Cloud ID, vegeu%s",
    "Share with me through my #Nextcloud Federated Cloud ID" : "Compartiu amb mi a través de la meva #Nextcloud Federated Cloud ID",
    "Sharing" : "Comparteix",
    "Federated file sharing" : "Compartició federada de fitxers",
    "Provide federated file sharing across servers" : "Proporcioneu compartició de fitxers federats entre servidors",
    "Federated Cloud Sharing" : "Compartició federada de núvol",
    "Open documentation" : "Obre la documentació",
    "Adjust how people can share between servers." : "Ajusteu com la gent pot compartir entre servidors.",
    "Allow users on this server to send shares to other servers" : "Permet als usuaris d'aquest servidor enviar comparticions a d'altres servidors",
    "Allow users on this server to receive shares from other servers" : "Permet als usuaris d'aquest servidor rebre comparticions a d'altres servidors",
    "Allow users on this server to send shares to groups on other servers" : "Permet als usuaris d'aquest servidor enviar comparticions a grups d'altres servidors",
    "Allow users on this server to receive group shares from other servers" : "Permet als usuaris d'aquest servidor rebre comparticions a grups d'altres servidors",
    "Search global and public address book for users" : "Cerca llibreta d'adreces global i pública per als usuaris",
    "Allow users to publish their data to a global and public address book" : "Permet als usuaris publicar les seves dades en una llibreta d'adreces global i pública",
    "Federated Cloud" : "Núvol federat",
    "You can share with anyone who uses a Nextcloud server or other Open Cloud Mesh (OCM) compatible servers and services! Just put their Federated Cloud ID in the share dialog. It looks like person@cloud.example.com" : "Podeu compartir amb qualsevol persona que faci servir un servidor Nextcloud o altres servidors i serveis compatibles amb Open Cloud Mesh (OCM)! Simplement poseu el seu ID de núvol federat al diàleg compartit. S'assembla a persona@cloud.example.com",
    "Your Federated Cloud ID:" : "El vostre ID de Núvol Federat:",
    "Share it so your friends can share files with you:" : "Compartiu-lo perquè els vostres amics us puguin compartir fitxers:",
    "Add to your website" : "Afegiu a la vostra pàgina web",
    "Share with me via Nextcloud" : "Comparteix amb mi mitjançant Nextcloud",
    "HTML Code:" : "Codi HTML:",
    "Sharing %s failed, because this item is already shared with %s" : "No s'ha pogut compartir %s, perquè l'element ja està compartit amb %s",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable or uses a self-signed certificate." : "Ha fallat la compartició %s, no s'ha pogut trobar%s, potser el servidor és inaccessible actualment o fa servir un certificat auto-signat."
},
"nplurals=2; plural=(n != 1);");
